@@ -3,7 +3,10 @@
 from .util import _parse_string_enum, _underlower, _enforce_type
 from .models import FormattingComponent, GridRange, _CLASSES
 
-from collections import MutableSequence, Iterable
+try:
+    from collections.abc import MutableSequence, Iterable
+except ImportError:
+    from collections import MutableSequence, Iterable
 
 
 def get_conditional_format_rules(worksheet):
@@ -77,7 +80,9 @@ class ConditionalFormatRules(MutableSequence):
         body = {
             'requests': delete_requests + add_requests
         }
-        return self.worksheet.spreadsheet.batch_update(body)
+        resp = self.worksheet.spreadsheet.batch_update(body)
+        self._original_rules = list(self.rules)
+        return resp
 
 
         
@@ -150,7 +155,7 @@ class BooleanCondition(ConditionalFormattingComponent):
         'BOOLEAN': (lambda x: isinstance(x, (list, tuple)) and len(x) >= 0 and len(x) <= 2)
     }
 
-    def __init__(self, type, values):
+    def __init__(self, type, values=()):
         self.type = _parse_string_enum("type", type, BooleanCondition.TYPES)
         validator = BooleanCondition.TYPES[self.type]
         valid = validator(values) if callable(validator) else len(values) == validator
